
### Network 1 (8 pipes, 1 valve, 1 reservoir, 7 junctions)

- B0   - Base Network (CFS)
- B0_1 - Valve closure (LPS)
- B0_0 - Valve openning (LPS)
- B1_1 - Dead end with flow (LPS)
- B1_0 - Dead end without flow (LPS)
- B2   - Nodes with elevations (LPS)
- B3   - Tank (LPS)
- B4   - Leak (LPS)
- B5   - Burst (LPS)